@@ -21,7 +21,7 @@ class InstabdClient:
         self.scope = scope
         self.client_secret = client_secret
 
-    def authorize(self):
+    def authorize(self, state=""):
         params = {
             "client_id": self.client_id,
             "redirect_uri": self.redirect_uri,
@@ -29,6 +29,9 @@ class InstabdClient:
             "response_type": "code",
         }
 
+        if state:
+            params.update({"state": state})
+
         url = (
             f"{self.API_ENDPOINT}/oauth/authorize?"
             f"{urllib.parse.urlencode(params)}"
